@@ -19,14 +19,20 @@ fn spl_token_id() -> Pubkey {
     Pubkey::new_from_array(spl_token::id().to_bytes())
 }
 
+// A helper function to convert spl_token_2022::id() as spl_sdk::pubkey::Pubkey to
+// solana_sdk::pubkey::Pubkey
+fn spl_token_2022_id() -> Pubkey {
+    Pubkey::new_from_array(spl_token_2022::id().to_bytes())
+}
+
 // Returns all known SPL Token program ids
 pub fn spl_token_ids() -> Vec<Pubkey> {
-    vec![spl_token_id()]
+    vec![spl_token_id(), spl_token_2022_id()]
 }
 
 // Check if the provided program id as a known SPL Token program id
 pub fn is_known_spl_token_id(program_id: &Pubkey) -> bool {
-    *program_id == spl_token_id()
+    *program_id == spl_token_id() || *program_id == spl_token_2022_id()
 }
 
 // A helper function to convert spl_token::native_mint::id() as spl_sdk::pubkey::Pubkey to
